cleaning warnings
diff --git a/doctest/doctest.h b/doctest/doctest.h
index 5fa29ed..4f48190 100644
--- a/doctest/doctest.h
+++ b/doctest/doctest.h
@@ -517,16 +517,16 @@
// for ending a testsuite block
#define DOCTEST_TESTSUITE_END void DOCTEST_ANONYMOUS(DOCTEST_AUTOGEN_FOR_SEMICOLON_)()
-#define DOCTEST_CHECK(expr) expr
-#define DOCTEST_CHECK_FALSE(expr) expr
-#define DOCTEST_CHECK_THROWS(expr) expr
-#define DOCTEST_CHECK_THROWS_AS(expr, ex) expr
-#define DOCTEST_CHECK_NOTHROW(expr) expr
-#define DOCTEST_REQUIRE(expr) expr
-#define DOCTEST_REQUIRE_FALSE(expr) expr
-#define DOCTEST_REQUIRE_THROWS(expr) expr
-#define DOCTEST_REQUIRE_THROWS_AS(expr, ex) expr
-#define DOCTEST_REQUIRE_NOTHROW(expr) expr
+#define DOCTEST_CHECK(expr) ((void)0)
+#define DOCTEST_CHECK_FALSE(expr) ((void)0)
+#define DOCTEST_CHECK_THROWS(expr) ((void)0)
+#define DOCTEST_CHECK_THROWS_AS(expr, ex) ((void)0)
+#define DOCTEST_CHECK_NOTHROW(expr) ((void)0)
+#define DOCTEST_REQUIRE(expr) ((void)0)
+#define DOCTEST_REQUIRE_FALSE(expr) ((void)0)
+#define DOCTEST_REQUIRE_THROWS(expr) ((void)0)
+#define DOCTEST_REQUIRE_THROWS_AS(expr, ex) ((void)0)
+#define DOCTEST_REQUIRE_NOTHROW(expr) ((void)0)
#endif // DOCTEST_DISABLE
diff --git a/examples/dev_testing/test.cpp b/examples/dev_testing/test.cpp
index 8517cf4..315f4e2 100644
--- a/examples/dev_testing/test.cpp
+++ b/examples/dev_testing/test.cpp
@@ -52,7 +52,14 @@
// test("") { printf("TEST %d\n", __LINE__); }
// test("") { printf("TEST %d\n", __LINE__); }
-void throws(); // to silence GCC "-Wmissing-declarations"
+// to silence GCC "-Wmissing-declarations"
+// and the attribute is to silence "-Wmissing-noreturn" on clang
+#ifdef __clang__
+void throws() __attribute__((noreturn));
+#else
+void throws();
+#endif
+
void throws() { throw std::exception(); }
void nothrows(); // to silence GCC "-Wmissing-declarations"
void nothrows() {}
diff --git a/examples/disabled/main.cpp b/examples/disabled/main.cpp
index a3d0986..dac9b46 100644
--- a/examples/disabled/main.cpp
+++ b/examples/disabled/main.cpp
@@ -12,7 +12,14 @@
testsuite(the testsuite!);
-void throws(); // to silence GCC "-Wmissing-declarations"
+// to silence GCC "-Wmissing-declarations"
+// and the attribute is to silence "-Wmissing-noreturn" on clang
+#ifdef __clang__
+void throws() __attribute__((noreturn));
+#else
+void throws();
+#endif
+
void throws() { throw std::exception(); }
void nothrows(); // to silence GCC "-Wmissing-declarations"
void nothrows() {}